import { NgParameter } from "../formulaire/ngparam";
import { Nub } from "jalhyd";
import { ServiceFactory } from "../services/service-factory";

export abstract class CalculatorResults {

    /**
     * 
     * @param p parameter to generate label for
     * @param displaySymbol if true, will prefix label with parameter symbol (ex: "ZDV")
     * @param referenceNub if given, will detect if parameter belongs to a child of this reference Nub, and
     *                     if so will add a number prefix (ex: "0_") before the label
     */
    public static paramLabel(p: NgParameter, displaySymbol: boolean, referenceNub?: Nub): string {
        let res = "";
        // detect child parameter
        let isChildParam = false;
        if (referenceNub) {
            const children = referenceNub.getChildren();
            const parameterNub = p.paramDefinition.parentNub;
            if (children.includes(parameterNub)) {
                isChildParam = true;
                const pos = parameterNub.findPositionInParent() + 1;
                res = ServiceFactory.instance.i18nService.localizeText("INFO_OUVRAGE_N") + pos + " : ";
            }
        }
        if (displaySymbol && ! isChildParam) {
            res += p.symbol;
        }
        if (p.label !== undefined && p.label !== "") {
            if (displaySymbol && ! isChildParam) {
                res += " : ";
            }
            res += p.label;
        }
        if (p.unit !== undefined && p.unit !== "") {
            res += " (" + p.unit + ")";
        }
        return res;
    }

    /**
     * remet tous les résultats à zero
     */
    protected abstract reset();

    /**
     * indique si il existe des résultats à afficher
     */
    public abstract get hasResults(): boolean;
}
